## 1.1.2 (2023-05-11)

### Refactor

- Replaced index_together with indexes

## 1.1.1 (2023-05-10)

### Fix

- Access attachment_set relation only on saved objects

## 1.1.0 (2023-02-04)

### Feat

- Export URL to file list

### Fix

- Fixed admin freeze if library don't exist
- Suppress setuptools warning

## 1.0.0 (2022-12-11)

## 0.0.1 (2022-12-11)

### Feat

- Implemented missing action get_library
- Added werkkzeug support to sample project
- Forwarded sign argument to list / update actions
- Allow forward signed parameter

### Fix

- Save admin attachments only after submit
- Fixed exception after save
- Update sample project
- Set default auto field to prevent migration generateion
- Suppressed warning
- Fixed for requests without HTTP_ACCEPT header

### Refactor

- Updated build system
